==> tuia-ecb-center-api-1.1.0.8-sources.jar: cn/com/duiba/tuia/ecb/center/mix/remoteservice/RemoteMixConfigService.java <==
package cn.com.duiba.tuia.ecb.center.mix.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ecb.center.mix.dto.MixCallbackLimitConfigDto;
import cn.com.duiba.tuia.ecb.center.mix.dto.MixConfigTemplateDTO;
import cn.com.duiba.tuia.ecb.center.mix.dto.video.MixAdvertConfigDto;
import cn.com.duiba.tuia.ecb.center.mix.dto.video.MixRewardVideoConfigDto;
import com.alibaba.fastjson.JSONObject;

/**
 * [工具类赚钱页]配置接口
 *
 * @author zhangbaiqiang
 * @date 2020/1/20
 */
@AdvancedFeignClient
public interface RemoteMixConfigService {

    /**
     * 获取媒体的配置模板
     */
    MixConfigTemplateDTO getConfigTemplateByAppId(Long appId);

    /**
     * 获取活动的配置模板
     */
    MixConfigTemplateDTO getConfigTemplateByActivityId(Long activityId);

    /**
     * 获取配置模板
     */
    MixConfigTemplateDTO getConfigTemplate(Long configTemplateId);

    /**
     * 更新媒体配置
     *
     * @param appId 媒体id
     * @param configTemplate 配置模板
     */
    void updateAppConfig(Long appId, MixConfigTemplateDTO configTemplate) throws BizException;

    /**
     * 更新活动配置
     *
     * @param activityId 活动id
     * @param configTemplate 配置模板
     */
    void updateActivityConfig(Long activityId, MixConfigTemplateDTO configTemplate) throws BizException;

    /**
     * 查询激励视频投放规则配置
     *
     * @param activityId 活动id
     * @return 激励视频投放规则配置
     */
    MixRewardVideoConfigDto getRewardVideoConfig(Long activityId);

    /**
     * 更新激励视频投放规则配置
     *
     * @param config 配置
     * @return 活动id
     */
    void updateRewardVideoConfig(Long activityId, MixRewardVideoConfigDto config);

    /**
     * 查询回调风控规则配置
     *
     * @return 回调风控规则配置
     */
    MixCallbackLimitConfigDto getCallbackLimitDefaultConfig();

    /**
     * 更新回调风控规则配置
     *
     * @param config 回调风控规则配置
     */
    void updateCallbackLimitDefaultConfig(MixCallbackLimitConfigDto config);

    /**
     * 清除媒体配置缓存，立即生效
     */
    void clearAppConfigCache(Long appId);

    /**
     * 清除活动配置缓存，立即生效
     */
    void clearActivityConfigCache(Long activityId);

    /*
    获取广告配置
     */
    MixAdvertConfigDto getAdvertConfig(Long activityId, Integer businessType);

    /*
    添加广告配置
     */
    Boolean addAdvertConfig(MixAdvertConfigDto configDto);

    /*
    更新广告配置
     */
    Boolean updateAdvertConfig(MixAdvertConfigDto configDto);

    /**
     * 保存广告配置
     */
    Boolean saveAdvertConfig(MixAdvertConfigDto configDto);

    /**
     * 校验赚钱页配置
     */
    JSONObject verifyConfig(Long appId, Long activityId);
}

==> tuia-ecb-center-api-1.1.0.8-20200304.035403-3-sources.jar: cn/com/duiba/tuia/ecb/center/mix/remoteservice/RemoteMixConfigService.java <==
package cn.com.duiba.tuia.ecb.center.mix.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ecb.center.mix.dto.MixCallbackLimitConfigDto;
import cn.com.duiba.tuia.ecb.center.mix.dto.MixConfigTemplateDTO;
import cn.com.duiba.tuia.ecb.center.mix.dto.video.MixRewardVideoConfigDto;

/**
 * [工具类赚钱页]配置接口
 *
 * @author zhangbaiqiang
 * @date 2020/1/20
 */
@AdvancedFeignClient
public interface RemoteMixConfigService {

    /**
     * 获取媒体的配置模板
     */
    MixConfigTemplateDTO getConfigTemplateByAppId(Long appId);

    /**
     * 获取活动的配置模板
     */
    MixConfigTemplateDTO getConfigTemplateByActivityId(Long activityId);

    /**
     * 获取配置模板
     */
    MixConfigTemplateDTO getConfigTemplate(Long configTemplateId);

    /**
     * 更新媒体配置
     *
     * @param appId 媒体id
     * @param configTemplate 配置模板
     */
    void updateAppConfig(Long appId, MixConfigTemplateDTO configTemplate);

    /**
     * 更新活动配置
     *
     * @param activityId 活动id
     * @param configTemplate 配置模板
     */
    void updateActivityConfig(Long activityId, MixConfigTemplateDTO configTemplate);

    /**
     * 查询激励视频投放规则配置
     *
     * @param activityId 活动id
     * @return 激励视频投放规则配置
     */
    MixRewardVideoConfigDto getRewardVideoConfig(Long activityId);

    /**
     * 更新激励视频投放规则配置
     *
     * @param config 配置
     * @return 活动id
     */
    void updateRewardVideoConfig(Long activityId, MixRewardVideoConfigDto config);

    /**
     * 查询回调风控规则配置
     *
     * @return 回调风控规则配置
     */
    MixCallbackLimitConfigDto getCallbackLimitDefaultConfig();

    /**
     * 更新回调风控规则配置
     *
     * @param config 回调风控规则配置
     */
    void updateCallbackLimitDefaultConfig(MixCallbackLimitConfigDto config);

    /**
     * 清除媒体配置缓存，立即生效
     */
    void clearAppConfigCache(Long appId);

    /**
     * 清除活动配置缓存，立即生效
     */
    void clearActivityConfigCache(Long activityId);
}
